﻿using System;

using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 셀 값 변경 여부
        /// </summary>
        private bool cellValueChanged = false;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                           += Form_Load;
            this.treeList.ShownEditor      += treeList_ShownEditor;
            this.treeList.HiddenEditor     += treeList_HiddenEditor;
            this.treeList.CellValueChanged += treeList_CellValueChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                              = 25;
            this.treeList.OptionsView.AutoWidth                  = false;
            this.treeList.OptionsBehavior.PopulateServiceColumns = true;
            this.treeList.KeyFieldName                           = "ID";
            this.treeList.ParentFieldName                        = "RegionID";

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            this.treeList.BestFitColumns();
        }

        #endregion
        #region 트리 리스트 에디터 표시시 처리하기 - treeList_ShownEditor(sender, e)

        /// <summary>
        /// 트리 리스트 에디터 표시시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_ShownEditor(object sender, EventArgs e)
        {
            TreeList treeList = sender as TreeList;

            treeList.FocusedNode.StateImageIndex = 2;

            this.cellValueChanged = false;
        }

        #endregion
        #region 트리 리스트 에디터 숨김시 처리하기 - treeList_HiddenEditor(sender, e)

        /// <summary>
        /// 트리 리스트 에디터 숨김시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_HiddenEditor(object sender, EventArgs e)
        {
            TreeList treeList = sender as TreeList;

            if(!this.cellValueChanged)
            {
                treeList.FocusedNode.StateImageIndex = 1;
            }
        }

        #endregion
        #region 트리 리스트 셀 값 변경시 처리하기 - treeList_CellValueChanged(sender, e)

        /// <summary>
        /// 트리 리스트 셀 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_CellValueChanged(object sender, CellValueChangedEventArgs e)
        {
            e.Node.StateImageIndex = 0;

            this.cellValueChanged = true;
        }

        #endregion
    }
}