﻿using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace TestProject
{
    /// <summary>
    /// 판매 데이터
    /// </summary>
    public class SalesData
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 고유 ID
        /// </summary>
        private static int UniqueID = 37;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region ID - ID

        /// <summary>
        /// ID
        /// </summary>
        public int ID { get; set; }

        #endregion
        #region 지역 ID - RegionID

        /// <summary>
        /// 지역 ID
        /// </summary>
        public int RegionID { get; set; }

        #endregion
        #region 영역 - Region

        /// <summary>
        /// 영역
        /// </summary>
        public string Region { get; set; }

        #endregion
        #region 3월 판매액 - MarchSales

        /// <summary>
        /// 3월 판매액
        /// </summary>
        public decimal MarchSales { get; set; }

        #endregion
        #region 9월 판매액 - SeptemberSales

        /// <summary>
        /// 9월 판매액
        /// </summary>
        public decimal SeptemberSales { get; set; }

        #endregion
        #region 시장 점유율 - MarketShare

        /// <summary>
        /// 시장 점유율
        /// </summary>
        [DisplayFormat(DataFormatString = "p0")]
        public double MarketShare { get; set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - SalesData()

        /// <summary>
        /// 생성자
        /// </summary>
        public SalesData()
        {
            ID = UniqueID++;
        }

        #endregion
        #region 생성자 - SalesData(id, regionID, region, marchSales, septemberSales, marketShare)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="id">ID</param>
        /// <param name="regionID">지역 ID</param>
        /// <param name="region">지역</param>
        /// <param name="marchSales">3월 판매액</param>
        /// <param name="septemberSales">9월 판매액</param>
        /// <param name="marketShare">시장 점유율</param>
        public SalesData(int id, int regionID, string region, decimal marchSales, decimal septemberSales, double marketShare)
        {
            ID             = id;
            RegionID       = regionID;
            Region         = region;
            MarchSales     = marchSales;
            SeptemberSales = septemberSales;
            MarketShare    = marketShare;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 판매 데이터 리스트 구하기 - GetSalesDataList()

        /// <summary>
        /// 판매 데이터 리스트 구하기
        /// </summary>
        /// <returns>판매 데이터 리스트</returns>
        public static List<SalesData> GetSalesDataList()
        {
            List<SalesData> list = new List<SalesData>();

            list.Add(new SalesData(0 , -1, "Western Europe", 30540, 33000, .70));
            list.Add(new SalesData(1 , 0, "Austria"        , 22000, 28000, .92));
            list.Add(new SalesData(2 , 0, "France"         , 23020, 27000, .51));
            list.Add(new SalesData(3 , 0, "Germany"        , 30540, 33000, .93));
            list.Add(new SalesData(4 , 0, "Spain"          , 12900, 10300, .82));
            list.Add(new SalesData(5 , 0, "Switzerland"    , 9323 , 10730, .14));
            list.Add(new SalesData(6 , 0, "United Kingdom" , 14580, 13967, .91));

            list.Add(new SalesData(17, -1, "Eastern Europe", 22500, 24580, .62));
            list.Add(new SalesData(18, 17, "Belarus"       , 7315 , 18800, .34));
            list.Add(new SalesData(19, 17, "Bulgaria"      , 6300 , 2821 , .8));
            list.Add(new SalesData(20, 17, "Croatia"       , 4200 , 3890 , .29));
            list.Add(new SalesData(21, 17, "Russia"        , 22500, 24580, .85));

            list.Add(new SalesData(26, -1, "North America" , 31400, 32800, .84));
            list.Add(new SalesData(27, 26, "USA"           , 31400, 32800, .87));
            list.Add(new SalesData(28, 26, "Canada"        , 25390, 27000, .64));

            list.Add(new SalesData(29, -1, "South America" , 16380, 17590, .32));
            list.Add(new SalesData(30, 29, "Argentina"     , 16380, 17590, .88));
            list.Add(new SalesData(31, 29, "Brazil"        , 4560 , 9480 , .10));

            list.Add(new SalesData(32, -1, "Asia"          , 20388, 22547, .52));
            list.Add(new SalesData(34, 32, "India"         , 4642 , 5320 , .44));
            list.Add(new SalesData(35, 32, "Japan"         , 9457 , 12859, .70));
            list.Add(new SalesData(36, 32, "China"         , 20388, 22547, .82));

            return list;
        }

        #endregion
    }
}